cmd

package
v0.0.0-...-5f1bfd3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 25, 2025 License: MIT Imports: 6 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute() error

Execute adds all child commands to the root command and sets flags appropriately.

func SetVersionInfo

func SetVersionInfo(v, c, b string)

SetVersionInfo sets the version information from the build process

Types

This section is empty.

Jump to